PROGRAM_NAME='VideoReQuest v1_1_0'
(************************************************************)
(* System Type : NetLinx									*)
(************************************************************)
(* REV HISTORY:												*)
(*  1.0.0	Initial Version									*)
(*  1.0.1	Fixed NVRam overflow when more than 7 panels	*)
(*			  are used.										*)
(*			Fixed video mode switching logic				*)
(*			Changed unused channel to 9999 and added error	*)
(*			  checking in the TP module to ignore any		*)
(*			  events attempting to use channel 9999			*)
(*			Added Browse by Cover Art capability			*)
(*  1.0.2	Fixed Browse by Cover Art issue where			*)
(*			  non-existant images would not get cleared.	*)
(*			Fixed a bug with plot summaries longer than		*)
(*			  2000 characters								*)
(*			Added Aspect Ratio feedback						*)
(*			Added Loading state feedback					*)
(*			Added single letter search keyboard				*)
(*  1.0.3	Added Debugging capability to module			*)
(*	1.1.0	Added new commands for VRQ FW v1.4.0			*)
(*			Added Browse Line Icons							*)
(*			Added Web Port to VRQ_COMM_DATA structure		*)
(************************************************************)
(*  **NOTE:  The source code for the 2 Module files is NOT	*)
(*           included in this demo.  You should not need	*)
(*           it, but you will get an error if you attempt	*)
(*           to build the whole system.						*)
(************************************************************)
(* Important Setup Information:								*)
(*   1) Add/Remove touch panel devices as necessary			*)
(*   2) For each touch panel that will control the			*)
(*      VideoReQuest, you need 1 instance of the			*)
(*      'VRQ TP UI v1_1_0' module (see below)				*)
(*   3) Open the 'VRQ Main v1_1_0.axi' file and modify the	*)
(*      IP Address or Baud Rate settings as necessary.		*)
(*      You can find and set the IP Address on the VRQ by	*)
(*      going to Menu-->Settings-->Network Configuration.	*)
(*      You can find and set the COM Port settings on the	*)
(*      VRQ by going to Menu-->Settings-->Control Port.		*)
(*      **NOTE:  If you change the Baud Rate or the IP		*)
(*               address on the VRQ, you MUST reboot the	*)
(*               VRQ for the settings to take effect.		*)
(*   4) Open the 'VRQ TP Interface v1_1_0.axi' include		*)
(*      file and the Page Name array or any of the Command	*)
(*      Channel arrays as necessary.  See comments in that	*)
(*      file for more information.							*)
(*   5) Add code at the bottom of this file (under the		*)
(*      "Define Program" section) to control your video		*)
(*      switcher.  The code is set to determine which		*)
(*      output should be used, you simply need to use that	*)
(*      code to control the switcher.						*)
(************************************************************)

(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE
dvVRQ1 = 0:2:0;          //Set the IP Address or Baud settings in the VRQ Main v1_1_0 file!!

vrqTP1 = 10001:2:0;      //Touch panel device 1
vrqTP2 = 10002:2:0;      //Touch panel device 2
vrqTP3 = 10003:2:0;      //Touch panel device 3

vdvVRQ1 = 34000:1:0;     //Virtual VRQ device
(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

#include 'VRQ Defines v1_1_0.axi';
#include 'VRQ Main v1_1_0.axi';
#include 'VRQ TP Interface v1_1_0.axi';

(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

/************************************************************
 You need 1 instance of the VRQ Comm v1_1_0 module for the
 VideoReQuest device.
*************************************************************/
DEFINE_MODULE 'VRQ Comm v1_1_0' VRQ_Comm_1   (dvVRQ1,                   //Actual VideoReQuest Device
                                              vdvVRQ1,                  //Virtual VideoReQuest Device
                                              VRQ_COMM_1.IP_ADDRESS,    //VideoReQuest IP Address
                                              VRQ_COMM_1.IP_PORT,       //VideoReQuest IP Port
                                              VRQ_COMM_1.WEB_PORT,      //VideoReQuest IP Port
                                              VRQ_COMM_1.BAUD_RATE,     //VideoReQuest Baud Rate
                                              VRQ_COMM_1.VIDEO_MODE,    //Video Output array
											  VRQ_COMM_1.ASPECT_RATIO); //Aspect Ratio of current movie


/************************************************************
 You need 1 instance of the VRQ TP UI v1_1_0 module for EACH
 touch screen that will control the VideoReQuest.  This demo
 is designed with 3.  Add/Remove these modules as necessary.
 **Be sure to change the name of the module (VRQ_TP_1, 2, 3, ...)
   and the vrqTP device name as necessary.  All other
   parameters should remain the same in each module.
*************************************************************/

DEFINE_MODULE 'VRQ TP UI v1_1_0' VRQ_TP_1    (vrqTP1,                 //Virtual Touch Panel Device
                                              vdvVRQ1,                //Virtual VideoReQuest Device
                                              VRQ_CMDS,               //VRQ Command Channel Array
                                              VRQ_LET_CH,             //VRQ Letters Channel Array
                                              VRQ_NUM_CH,             //VRQ Numbers Channel Array
                                              VRQ_FB_CH,              //VRQ Variable Text Channel Array
                                              VRQ_PAGES,              //VRQ Page Name Array
                                              VRQ_NAV_THUMB_IMAGES,   //VRQ Browse thumbnail image resource names
                                              VRQ_NAV_FULL_IMAGES,    //VRQ Browse large image resource names
                                              VRQ_PLAYER_IMAGE,       //VRQ Player Cover Art Image
                                              VRQ_SYSTEM_ICONS,       //VRQ Player Cover Art Image
                                              VRQ_BROWSE_BY_COVERS,   //VRQ_BROWSE_BY_LIST or VRQ_BROWSE_BY_COVERS
                                              VRQ_LINE_PRESS_DOUBLE); //VRQ Line Press Type (single or double)

DEFINE_MODULE 'VRQ TP UI v1_1_0' VRQ_TP_2    (vrqTP2,                 //Virtual Touch Panel Device
                                              vdvVRQ1,                //Virtual VideoReQuest Device
                                              VRQ_CMDS,               //VRQ Command Channel Array
                                              VRQ_LET_CH,             //VRQ Letters Channel Array
                                              VRQ_NUM_CH,             //VRQ Numbers Channel Array
                                              VRQ_FB_CH,              //VRQ Variable Text Channel Array
                                              VRQ_PAGES,              //VRQ Page Name Array
                                              VRQ_NAV_THUMB_IMAGES,   //VRQ Browse thumbnail image resource names
                                              VRQ_NAV_FULL_IMAGES,    //VRQ Browse large image resource names
                                              VRQ_PLAYER_IMAGE,       //VRQ Player Cover Art Image
                                              VRQ_SYSTEM_ICONS,       //VRQ Player Cover Art Image
                                              VRQ_BROWSE_BY_LIST,     //VRQ_BROWSE_BY_LIST or VRQ_BROWSE_BY_COVERS
                                              VRQ_LINE_PRESS_DOUBLE); //VRQ Line Press Type (single or double)

DEFINE_MODULE 'VRQ TP UI v1_1_0' VRQ_TP_3    (vrqTP3,                 //Virtual Touch Panel Device
                                              vdvVRQ1,                //Virtual VideoReQuest Device
                                              VRQ_CMDS,               //VRQ Command Channel Array
                                              VRQ_LET_CH,             //VRQ Letters Channel Array
                                              VRQ_NUM_CH,             //VRQ Numbers Channel Array
                                              VRQ_FB_CH,              //VRQ Variable Text Channel Array
                                              VRQ_PAGES,              //VRQ Page Name Array
                                              VRQ_NAV_THUMB_IMAGES,   //VRQ Browse thumbnail image resource names
                                              VRQ_NAV_FULL_IMAGES,    //VRQ Browse large image resource names
                                              VRQ_PLAYER_IMAGE,       //VRQ Player Cover Art Image
                                              VRQ_SYSTEM_ICONS,       //VRQ Player Cover Art Image
                                              VRQ_BROWSE_BY_LIST,     //VRQ_BROWSE_BY_LIST or VRQ_BROWSE_BY_COVERS
                                              VRQ_LINE_PRESS_DOUBLE); //VRQ Line Press Type (single or double)

(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
DEFINE_EVENT

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

IF(VRQ_COMM_1.VIDEO_MODE[6]) {	//Indicates that the video mode has changed
	VRQ_COMM_1.VIDEO_MODE[6] = 0
	
	IF(VRQ_COMM_1.VIDEO_MODE[1]) {
		//Add code HERE to switch video to VRQ output
	}
	IF(VRQ_COMM_1.VIDEO_MODE[2]) {
		//Add code HERE to switch video to Changer 1 Output
		SEND_STRING 0, "'Changer 1 Aspect Ratio = ', FTOA(VRQ_COMM_1.ASPECT_RATIO)"
	}
	IF(VRQ_COMM_1.VIDEO_MODE[3]) {
		//Add code HERE to switch video to Changer 2 Output
		SEND_STRING 0, "'Changer 2 Aspect Ratio = ', FTOA(VRQ_COMM_1.ASPECT_RATIO)"
	}
	IF(VRQ_COMM_1.VIDEO_MODE[4]) {
		//Add code HERE to switch video to Changer 3 Output
		SEND_STRING 0, "'Changer 3 Aspect Ratio = ', FTOA(VRQ_COMM_1.ASPECT_RATIO)"
	}
	IF(VRQ_COMM_1.VIDEO_MODE[5]) {
		//Add code HERE to switch video to Changer 4 Output
		SEND_STRING 0, "'Changer 4 Aspect Ratio = ', FTOA(VRQ_COMM_1.ASPECT_RATIO)"
	}
	
	//Add code HERE to adjust screen size based on Aspect Ratio
	//Use VRQ_COMM_1.ASPECT_RATIO to obtain the aspect ratio (FLOAT)
}


(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

